import React from 'react';

import HeadView from '../view/HeadView';
import TableBtnView from '../view/TableBtnView';
import CommonSearchForm from '../view/CommonSearchForm';
import { Input, Button, DatePicker, Divider, message, Popconfirm, Select, Badge, Tooltip } from 'antd';
import moment from 'moment';
import Fetch from '../fetch';
import TableView from '../view/TableView';
const Option = Select.Option;
function typeOfName(type) {
    switch (type) {
        case 1:
            return "待处理";
        case 2:
            return "已受理";
        case 3:
            return "已反馈";
    }
}
export default class ApplyFor extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            data: [],
            formData: {
                __key: Date.now(),
                page: 1,
                size: 10,
            },
            resetKey: Date.now(),
            loading: false
        };
    }

    componentDidMount() {

        document.title = '检察院审核';
        this.getData();
    }

    setFormData = data => {
        console.log('form', data);
        this.setState({
            formData: data,
        });
    }

    searchonClick = data => {
        console.log('form', data);
        this.setState({
            formData: data,
        });
        this.setState({ loading: true })
        Fetch.entryQuery({ ...data, type: 2 })
            .then(res => {
                console.log(res)
                for (var i = 0; i < res.rows.length; i++) {
                    res.rows[i]['index'] = i + 1;
                }
                this.setState({
                    data: res.rows,
                    loading: false
                });
            });
    }

    getData = () => {
        this.setState({ loading: true })
        console.log(this.state.formData)
        Fetch.entryQuery({ ...this.state.formData, type: 2 })
            .then(res => {
                console.log(res)
                for (var i = 0; i < res.rows.length; i++) {
                    res.rows[i]['index'] = i + 1;
                }
                this.setState({
                    data: res.rows,
                    loading: false
                });
            });
    }
    onInputChange = ({ target: { value, name } }) => {
        this.setState(({ formData }) => ({
            formData: {
                ...formData,
                [name]: value
            }
        }))
    }
    showModal = (id) => {
        this.props.history.push("/entry/ExamineEdit/" + id);
    }

    confirm = (e) => {
        console.log(e);
        this.setState({ loading: true })
        Fetch.socialDelete(e).then(res => {
            if (res.code == 0) {
                console.log(res)
                this.setState({ loading: false })
                message.success('删除成功');
                this.getData();
            } else {
                this.setState({ loading: false })
                message.error('删除失败，请联系管理员', 2)
            }
        }
        )
    }
    render() {
        const columns = [{
            title: '申请人',
            dataIndex: 'createrName',
            key: 'createrName'
        }, {
            title: '申请时间',
            dataIndex: 'createTime',
            key: 'createTime',
            render: text => <span>{moment(text).format("YYYY-MM-DD HH:mm")}</span>
        }, {
            title: '申请理由',
            dataIndex: 'reason',
            key: 'reason',
            render: text => <Tooltip title={text}>
                <span width='500px'>{text}</span>
            </Tooltip>
        }, {
            title: '状态',
            dataIndex: 'status',
            key: 'status',
            render: text => (
                text == 1 ? <Badge style={{ backgroundColor: '#6C757C' }} count={'待处理'} /> : text == 2 ? <Badge style={{ backgroundColor: '#F1C40F' }} count={'已受理'} /> : <Badge style={{ backgroundColor: '#2ECC71' }} count={'已反馈'} />
            )
        }, {
            title: '操作',
            key: 'action',
            render: (text, record) => (
                record.status == 1 ?
                    <span>
                        <a onClick={() => this.showModal(record.id)}>审核</a>
                    </span>
                    : <span>
                        <a onClick={() => this.showModal(record.id)}>详情</a>
                    </span>
            ),
        }];
        const { data, loading, resetKey, formData } = this.state;
        console.log(formData)
        return (
            <div className="app-page">
                <HeadView history={this.props.history} />
                <div style={{ background: '#fff', margin: 20 }}>
                    <CommonSearchForm
                        {...this.props}
                        formData={formData}
                        setFormData={this.setFormData}
                        searchonClick={this.searchonClick}
                        pathName={this.props.location.pathname}
                        data={[
                            { type: 'input', name: '申请人', label: '申请人', key: 'createrName' },
                            {
                                type: 'rangePicker',
                                label: '申请时间',
                                name: JSON.stringify(['开始时间', '结束时间']),
                                key: JSON.stringify(['startTime', 'endTime']),
                                keylistName: 'rangeTimelist',
                            },
                        ]} />
                    <TableView columns={columns} data={data} pageSize='10' size='default' loading={loading} />
                </div>
            </div>
        );
    }

}
